/*
 * Copyright 2015 Main Street Softworks, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, this list of
 *     conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice, this list
 *     of conditions and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY MAIN STREET SOFTWORKS INC ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL MAIN STREET SOFTWORKS INC OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are those of the
 * authors and should not be interpreted as representing official policies, either expressed
 * or implied, of Main Street Softworks, Inc.
 */

package com.monetra.uniterm.servicetest;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.content.ComponentName;
import android.os.IBinder;
import android.content.ServiceConnection;
import android.view.View;
import android.widget.EditText;

import com.monetra.uniterm.service.IUnitermService;
import com.monetra.uniterm.service.UnitermService;


public class MainActivity extends Activity {

    private IUnitermService mUnitermService = null;
    private ServiceConnection mUnitermServiceConnection = new ServiceConnection() {
        @Override
        public void onServiceConnected(ComponentName name, IBinder service) {
            synchronized (this) {
                mUnitermService = IUnitermService.Stub.asInterface(service);
            }
        }

        @Override
        public void onServiceDisconnected(ComponentName name) {
            synchronized (this) {
                mUnitermService = null;
            }
        }
    };

    private void runTrans(String title, final Bundle req) {
        Bundle rsp;
        String ver;

        try {
            rsp = mUnitermService.runTrans(req);
        } catch (Exception e) {
            rsp = new Bundle();
            rsp.putString("verbiage", e.getMessage());
        }

        AlertDialog alertDialog = new AlertDialog.Builder(MainActivity.this).create();
        alertDialog.setTitle(title);
        if (rsp.containsKey("verbiage")) {
            ver = rsp.getString("verbiage");
        } else {
            ver = "Unknown";
        }
        alertDialog.setMessage(ver);
        alertDialog.setButton(AlertDialog.BUTTON_NEUTRAL, "OK",
                new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int which) {
                        dialog.dismiss();
                    }
                });
        alertDialog.show();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        Intent i = new Intent(this, UnitermService.class);
        this.bindService(i, mUnitermServiceConnection, Context.BIND_AUTO_CREATE);
    }

    protected void finalize() {
        if (mUnitermServiceConnection != null)
            this.unbindService(mUnitermServiceConnection);
    }

    public void on_checkpwd(View view) {
        Bundle req = new Bundle();

        req.putString("u_action", "passthrough");
        req.putString("action", "chkpwd");
        req.putString("username", ((EditText)(findViewById(R.id.username))).getText().toString());
        req.putString("password",((EditText)(findViewById(R.id.password))).getText().toString());

        runTrans("Check Password", req);
    }

    public void on_changeserver(View view) {
        Bundle req = new Bundle();
        boolean ret;

        req.putString("monetra.host", ((EditText)(findViewById(R.id.server))).getText().toString());

        try {
             ret = mUnitermService.modifyConfig(req);
        } catch (Exception e) {
            ret = false;
        }
        AlertDialog alertDialog = new AlertDialog.Builder(MainActivity.this).create();
        alertDialog.setTitle("Modify Config");
        alertDialog.setMessage(ret?"Success":"Fail");
        alertDialog.setButton(AlertDialog.BUTTON_NEUTRAL, "OK",
                new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int which) {
                        dialog.dismiss();
                    }
                });
        alertDialog.show();
    }

    public void on_version(View view) {
        Bundle req = new Bundle();;

        req.putString("u_action", "version");

        runTrans("Versin", req);
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onStop() {
        super.onStop();
    }
}
